Introduction
============

This package provides the demo views for
`collective.z3cform.datagridfield <https://github.com/collective/collective.z3cform.datagridfield>`_. See that
package for more information.

Installation
------------

Add collective.z3cform.datagridfield_demo to your buildout eggs.::

    eggs=\
        ...
        collective.z3cform.datagridfield
        collective.z3cform.datagridfield_demo

Examples of configurations are in the demo folder.

Install ``collective.z3cform.datagridfield`` in *Site setup* > *Add ons*.

Once you install this package (no add-on installer installation required),
the demo views will be visible on your site.

* http://localhost:8080/Plone/@@demo-collective.z3cform.datagrid

This page has links of several examples of different DGF use cases.

Sample output
---------------

Run Plone on foreground mode to see debug prints what kind of data the demo forms submit.

Source code and issue tracker
-------------------------------

* https://github.com/collective/collective.z3cform.datagridfield_demo

References
----------

    * http://pypi.python.org/pypi/collective.z3cform.datagridfield


